# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/decl.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1beta1 import expr_pb2 as google_dot_api_dot_expr_dot_v1beta1_dot_expr__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1beta1/decl.proto',
  package='google.api.expr.v1beta1',
  syntax='proto3',
  serialized_options=b'\n\033com.google.api.expr.v1beta1B\tDeclProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"google/api/expr/v1beta1/decl.proto\x12\x17google.api.expr.v1beta1\x1a\"google/api/expr/v1beta1/expr.proto\"\xa5\x01\n\x04\x44\x65\x63l\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03\x64oc\x18\x03 \x01(\t\x12\x33\n\x05ident\x18\x04 \x01(\x0b\x32\".google.api.expr.v1beta1.IdentDeclH\x00\x12\x39\n\x08\x66unction\x18\x05 \x01(\x0b\x32%.google.api.expr.v1beta1.FunctionDeclH\x00\x42\x06\n\x04kind\"\\\n\x08\x44\x65\x63lType\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x36\n\x0btype_params\x18\x04 \x03(\x0b\x32!.google.api.expr.v1beta1.DeclType\"j\n\tIdentDecl\x12/\n\x04type\x18\x03 \x01(\x0b\x32!.google.api.expr.v1beta1.DeclType\x12,\n\x05value\x18\x04 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\"\x93\x01\n\x0c\x46unctionDecl\x12\x30\n\x04\x61rgs\x18\x01 \x03(\x0b\x32\".google.api.expr.v1beta1.IdentDecl\x12\x36\n\x0breturn_type\x18\x02 \x01(\x0b\x32!.google.api.expr.v1beta1.DeclType\x12\x19\n\x11receiver_function\x18\x03 \x01(\x08\x42j\n\x1b\x63om.google.api.expr.v1beta1B\tDeclProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_expr_dot_v1beta1_dot_expr__pb2.DESCRIPTOR,])




_DECL = _descriptor.Descriptor(
  name='Decl',
  full_name='google.api.expr.v1beta1.Decl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.expr.v1beta1.Decl.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.api.expr.v1beta1.Decl.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doc', full_name='google.api.expr.v1beta1.Decl.doc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ident', full_name='google.api.expr.v1beta1.Decl.ident', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='google.api.expr.v1beta1.Decl.function', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='google.api.expr.v1beta1.Decl.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=100,
  serialized_end=265,
)


_DECLTYPE = _descriptor.Descriptor(
  name='DeclType',
  full_name='google.api.expr.v1beta1.DeclType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.expr.v1beta1.DeclType.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.api.expr.v1beta1.DeclType.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_params', full_name='google.api.expr.v1beta1.DeclType.type_params', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=359,
)


_IDENTDECL = _descriptor.Descriptor(
  name='IdentDecl',
  full_name='google.api.expr.v1beta1.IdentDecl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.api.expr.v1beta1.IdentDecl.type', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1beta1.IdentDecl.value', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=467,
)


_FUNCTIONDECL = _descriptor.Descriptor(
  name='FunctionDecl',
  full_name='google.api.expr.v1beta1.FunctionDecl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='args', full_name='google.api.expr.v1beta1.FunctionDecl.args', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_type', full_name='google.api.expr.v1beta1.FunctionDecl.return_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver_function', full_name='google.api.expr.v1beta1.FunctionDecl.receiver_function', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=617,
)

_DECL.fields_by_name['ident'].message_type = _IDENTDECL
_DECL.fields_by_name['function'].message_type = _FUNCTIONDECL
_DECL.oneofs_by_name['kind'].fields.append(
  _DECL.fields_by_name['ident'])
_DECL.fields_by_name['ident'].containing_oneof = _DECL.oneofs_by_name['kind']
_DECL.oneofs_by_name['kind'].fields.append(
  _DECL.fields_by_name['function'])
_DECL.fields_by_name['function'].containing_oneof = _DECL.oneofs_by_name['kind']
_DECLTYPE.fields_by_name['type_params'].message_type = _DECLTYPE
_IDENTDECL.fields_by_name['type'].message_type = _DECLTYPE
_IDENTDECL.fields_by_name['value'].message_type = google_dot_api_dot_expr_dot_v1beta1_dot_expr__pb2._EXPR
_FUNCTIONDECL.fields_by_name['args'].message_type = _IDENTDECL
_FUNCTIONDECL.fields_by_name['return_type'].message_type = _DECLTYPE
DESCRIPTOR.message_types_by_name['Decl'] = _DECL
DESCRIPTOR.message_types_by_name['DeclType'] = _DECLTYPE
DESCRIPTOR.message_types_by_name['IdentDecl'] = _IDENTDECL
DESCRIPTOR.message_types_by_name['FunctionDecl'] = _FUNCTIONDECL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Decl = _reflection.GeneratedProtocolMessageType('Decl', (_message.Message,), {
  'DESCRIPTOR' : _DECL,
  '__module__' : 'google.api.expr.v1beta1.decl_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.Decl)
  })
_sym_db.RegisterMessage(Decl)

DeclType = _reflection.GeneratedProtocolMessageType('DeclType', (_message.Message,), {
  'DESCRIPTOR' : _DECLTYPE,
  '__module__' : 'google.api.expr.v1beta1.decl_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.DeclType)
  })
_sym_db.RegisterMessage(DeclType)

IdentDecl = _reflection.GeneratedProtocolMessageType('IdentDecl', (_message.Message,), {
  'DESCRIPTOR' : _IDENTDECL,
  '__module__' : 'google.api.expr.v1beta1.decl_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.IdentDecl)
  })
_sym_db.RegisterMessage(IdentDecl)

FunctionDecl = _reflection.GeneratedProtocolMessageType('FunctionDecl', (_message.Message,), {
  'DESCRIPTOR' : _FUNCTIONDECL,
  '__module__' : 'google.api.expr.v1beta1.decl_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.FunctionDecl)
  })
_sym_db.RegisterMessage(FunctionDecl)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/matching/v3/extension_matcher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.common.matcher.v3 import matcher_pb2 as envoy_dot_config_dot_common_dot_matcher_dot_v3_dot_matcher__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/common/matching/v3/extension_matcher.proto',
  package='envoy.extensions.common.matching.v3',
  syntax='proto3',
  serialized_options=b'\n1io.envoyproxy.envoy.extensions.common.matching.v3B\025ExtensionMatcherProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;envoy/extensions/common/matching/v3/extension_matcher.proto\x12#envoy.extensions.common.matching.v3\x1a,envoy/config/common/matcher/v3/matcher.proto\x1a$envoy/config/core/v3/extension.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xaa\x01\n\x14\x45xtensionWithMatcher\x12\x42\n\x07matcher\x18\x01 \x01(\x0b\x32\'.envoy.config.common.matcher.v3.MatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12N\n\x10\x65xtension_config\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42T\n1io.envoyproxy.envoy.extensions.common.matching.v3B\x15\x45xtensionMatcherProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_common_dot_matcher_dot_v3_dot_matcher__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_extension__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_EXTENSIONWITHMATCHER = _descriptor.Descriptor(
  name='ExtensionWithMatcher',
  full_name='envoy.extensions.common.matching.v3.ExtensionWithMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matcher', full_name='envoy.extensions.common.matching.v3.ExtensionWithMatcher.matcher', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_config', full_name='envoy.extensions.common.matching.v3.ExtensionWithMatcher.extension_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=411,
)

_EXTENSIONWITHMATCHER.fields_by_name['matcher'].message_type = envoy_dot_config_dot_common_dot_matcher_dot_v3_dot_matcher__pb2._MATCHER
_EXTENSIONWITHMATCHER.fields_by_name['extension_config'].message_type = envoy_dot_config_dot_core_dot_v3_dot_extension__pb2._TYPEDEXTENSIONCONFIG
DESCRIPTOR.message_types_by_name['ExtensionWithMatcher'] = _EXTENSIONWITHMATCHER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtensionWithMatcher = _reflection.GeneratedProtocolMessageType('ExtensionWithMatcher', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONWITHMATCHER,
  '__module__' : 'envoy.extensions.common.matching.v3.extension_matcher_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.common.matching.v3.ExtensionWithMatcher)
  })
_sym_db.RegisterMessage(ExtensionWithMatcher)


DESCRIPTOR._options = None
_EXTENSIONWITHMATCHER.fields_by_name['matcher']._options = None
_EXTENSIONWITHMATCHER.fields_by_name['extension_config']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v2/opencensus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from opencensus.proto.trace.v1 import trace_config_pb2 as opencensus_dot_proto_dot_trace_dot_v1_dot_trace__config__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/trace/v2/opencensus.proto',
  package='envoy.config.trace.v2',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.config.trace.v2B\017OpencensusProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&envoy/config/trace/v2/opencensus.proto\x12\x15\x65nvoy.config.trace.v2\x1a$envoy/api/v2/core/grpc_service.proto\x1a,opencensus/proto/trace/v1/trace_config.proto\x1a\x1dudpa/annotations/status.proto\"\xd8\x05\n\x10OpenCensusConfig\x12<\n\x0ctrace_config\x18\x01 \x01(\x0b\x32&.opencensus.proto.trace.v1.TraceConfig\x12\x1f\n\x17stdout_exporter_enabled\x18\x02 \x01(\x08\x12$\n\x1cstackdriver_exporter_enabled\x18\x03 \x01(\x08\x12\x1e\n\x16stackdriver_project_id\x18\x04 \x01(\t\x12\x1b\n\x13stackdriver_address\x18\n \x01(\t\x12@\n\x18stackdriver_grpc_service\x18\r \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcService\x12\x1f\n\x17zipkin_exporter_enabled\x18\x05 \x01(\x08\x12\x12\n\nzipkin_url\x18\x06 \x01(\t\x12 \n\x18ocagent_exporter_enabled\x18\x0b \x01(\x08\x12\x17\n\x0focagent_address\x18\x0c \x01(\t\x12<\n\x14ocagent_grpc_service\x18\x0e \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcService\x12T\n\x16incoming_trace_context\x18\x08 \x03(\x0e\x32\x34.envoy.config.trace.v2.OpenCensusConfig.TraceContext\x12T\n\x16outgoing_trace_context\x18\t \x03(\x0e\x32\x34.envoy.config.trace.v2.OpenCensusConfig.TraceContext\"`\n\x0cTraceContext\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rTRACE_CONTEXT\x10\x01\x12\x12\n\x0eGRPC_TRACE_BIN\x10\x02\x12\x17\n\x13\x43LOUD_TRACE_CONTEXT\x10\x03\x12\x06\n\x02\x42\x33\x10\x04J\x04\x08\x07\x10\x08\x42@\n#io.envoyproxy.envoy.config.trace.v2B\x0fOpencensusProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2.DESCRIPTOR,opencensus_dot_proto_dot_trace_dot_v1_dot_trace__config__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])



_OPENCENSUSCONFIG_TRACECONTEXT = _descriptor.EnumDescriptor(
  name='TraceContext',
  full_name='envoy.config.trace.v2.OpenCensusConfig.TraceContext',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRACE_CONTEXT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRPC_TRACE_BIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOUD_TRACE_CONTEXT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='B3', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=807,
  serialized_end=903,
)
_sym_db.RegisterEnumDescriptor(_OPENCENSUSCONFIG_TRACECONTEXT)


_OPENCENSUSCONFIG = _descriptor.Descriptor(
  name='OpenCensusConfig',
  full_name='envoy.config.trace.v2.OpenCensusConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace_config', full_name='envoy.config.trace.v2.OpenCensusConfig.trace_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stdout_exporter_enabled', full_name='envoy.config.trace.v2.OpenCensusConfig.stdout_exporter_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stackdriver_exporter_enabled', full_name='envoy.config.trace.v2.OpenCensusConfig.stackdriver_exporter_enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stackdriver_project_id', full_name='envoy.config.trace.v2.OpenCensusConfig.stackdriver_project_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stackdriver_address', full_name='envoy.config.trace.v2.OpenCensusConfig.stackdriver_address', index=4,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stackdriver_grpc_service', full_name='envoy.config.trace.v2.OpenCensusConfig.stackdriver_grpc_service', index=5,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zipkin_exporter_enabled', full_name='envoy.config.trace.v2.OpenCensusConfig.zipkin_exporter_enabled', index=6,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zipkin_url', full_name='envoy.config.trace.v2.OpenCensusConfig.zipkin_url', index=7,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocagent_exporter_enabled', full_name='envoy.config.trace.v2.OpenCensusConfig.ocagent_exporter_enabled', index=8,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocagent_address', full_name='envoy.config.trace.v2.OpenCensusConfig.ocagent_address', index=9,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocagent_grpc_service', full_name='envoy.config.trace.v2.OpenCensusConfig.ocagent_grpc_service', index=10,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='incoming_trace_context', full_name='envoy.config.trace.v2.OpenCensusConfig.incoming_trace_context', index=11,
      number=8, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outgoing_trace_context', full_name='envoy.config.trace.v2.OpenCensusConfig.outgoing_trace_context', index=12,
      number=9, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPENCENSUSCONFIG_TRACECONTEXT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=909,
)

_OPENCENSUSCONFIG.fields_by_name['trace_config'].message_type = opencensus_dot_proto_dot_trace_dot_v1_dot_trace__config__pb2._TRACECONFIG
_OPENCENSUSCONFIG.fields_by_name['stackdriver_grpc_service'].message_type = envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2._GRPCSERVICE
_OPENCENSUSCONFIG.fields_by_name['ocagent_grpc_service'].message_type = envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2._GRPCSERVICE
_OPENCENSUSCONFIG.fields_by_name['incoming_trace_context'].enum_type = _OPENCENSUSCONFIG_TRACECONTEXT
_OPENCENSUSCONFIG.fields_by_name['outgoing_trace_context'].enum_type = _OPENCENSUSCONFIG_TRACECONTEXT
_OPENCENSUSCONFIG_TRACECONTEXT.containing_type = _OPENCENSUSCONFIG
DESCRIPTOR.message_types_by_name['OpenCensusConfig'] = _OPENCENSUSCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OpenCensusConfig = _reflection.GeneratedProtocolMessageType('OpenCensusConfig', (_message.Message,), {
  'DESCRIPTOR' : _OPENCENSUSCONFIG,
  '__module__' : 'envoy.config.trace.v2.opencensus_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.trace.v2.OpenCensusConfig)
  })
_sym_db.RegisterMessage(OpenCensusConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/month.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/type/month.proto',
  package='google.type',
  syntax='proto3',
  serialized_options=b'\n\017com.google.typeB\nMonthProtoP\001Z6google.golang.org/genproto/googleapis/type/month;month\242\002\003GTP',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17google/type/month.proto\x12\x0bgoogle.type*\xb0\x01\n\x05Month\x12\x15\n\x11MONTH_UNSPECIFIED\x10\x00\x12\x0b\n\x07JANUARY\x10\x01\x12\x0c\n\x08\x46\x45\x42RUARY\x10\x02\x12\t\n\x05MARCH\x10\x03\x12\t\n\x05\x41PRIL\x10\x04\x12\x07\n\x03MAY\x10\x05\x12\x08\n\x04JUNE\x10\x06\x12\x08\n\x04JULY\x10\x07\x12\n\n\x06\x41UGUST\x10\x08\x12\r\n\tSEPTEMBER\x10\t\x12\x0b\n\x07OCTOBER\x10\n\x12\x0c\n\x08NOVEMBER\x10\x0b\x12\x0c\n\x08\x44\x45\x43\x45MBER\x10\x0c\x42]\n\x0f\x63om.google.typeB\nMonthProtoP\x01Z6google.golang.org/genproto/googleapis/type/month;month\xa2\x02\x03GTPb\x06proto3'
)

_MONTH = _descriptor.EnumDescriptor(
  name='Month',
  full_name='google.type.Month',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MONTH_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JANUARY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEBRUARY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARCH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APRIL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JUNE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JULY', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUGUST', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEPTEMBER', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OCTOBER', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOVEMBER', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DECEMBER', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=41,
  serialized_end=217,
)
_sym_db.RegisterEnumDescriptor(_MONTH)

Month = enum_type_wrapper.EnumTypeWrapper(_MONTH)
MONTH_UNSPECIFIED = 0
JANUARY = 1
FEBRUARY = 2
MARCH = 3
APRIL = 4
MAY = 5
JUNE = 6
JULY = 7
AUGUST = 8
SEPTEMBER = 9
OCTOBER = 10
NOVEMBER = 11
DECEMBER = 12


DESCRIPTOR.enum_types_by_name['Month'] = _MONTH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/listener/listener.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.listener import listener_components_pb2 as envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2

from envoy.api.v2.listener.listener_components_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/listener/listener.proto',
  package='envoy.api.v2.listener',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.api.v2.listenerB\rListenerProtoP\001\252\002\027Envoy.Api.V2.ListenerNS\352\002\027Envoy.Api.V2.ListenerNS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/api/v2/listener/listener.proto\x12\x15\x65nvoy.api.v2.listener\x1a/envoy/api/v2/listener/listener_components.protoBj\n#io.envoyproxy.envoy.api.v2.listenerB\rListenerProtoP\x01\xaa\x02\x17\x45nvoy.Api.V2.ListenerNS\xea\x02\x17\x45nvoy.Api.V2.ListenerNSP\x00\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/tap/v2alpha/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.common.tap.v2alpha import common_pb2 as envoy_dot_config_dot_common_dot_tap_dot_v2alpha_dot_common__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/tap/v2alpha/tap.proto',
  package='envoy.config.filter.http.tap.v2alpha',
  syntax='proto3',
  serialized_options=b'\n2io.envoyproxy.envoy.config.filter.http.tap.v2alphaB\010TapProtoP\001\362\230\376\217\005&\022$envoy.extensions.filters.http.tap.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.envoy/config/filter/http/tap/v2alpha/tap.proto\x12$envoy.config.filter.http.tap.v2alpha\x1a,envoy/config/common/tap/v2alpha/common.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"^\n\x03Tap\x12W\n\rcommon_config\x18\x01 \x01(\x0b\x32\x36.envoy.config.common.tap.v2alpha.CommonExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42t\n2io.envoyproxy.envoy.config.filter.http.tap.v2alphaB\x08TapProtoP\x01\xf2\x98\xfe\x8f\x05&\x12$envoy.extensions.filters.http.tap.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_common_dot_tap_dot_v2alpha_dot_common__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TAP = _descriptor.Descriptor(
  name='Tap',
  full_name='envoy.config.filter.http.tap.v2alpha.Tap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.config.filter.http.tap.v2alpha.Tap.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=316,
)

_TAP.fields_by_name['common_config'].message_type = envoy_dot_config_dot_common_dot_tap_dot_v2alpha_dot_common__pb2._COMMONEXTENSIONCONFIG
DESCRIPTOR.message_types_by_name['Tap'] = _TAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tap = _reflection.GeneratedProtocolMessageType('Tap', (_message.Message,), {
  'DESCRIPTOR' : _TAP,
  '__module__' : 'envoy.config.filter.http.tap.v2alpha.tap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.tap.v2alpha.Tap)
  })
_sym_db.RegisterMessage(Tap)


DESCRIPTOR._options = None
_TAP.fields_by_name['common_config']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/auth/v3/external_auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.service.auth.v3 import attribute_context_pb2 as envoy_dot_service_dot_auth_dot_v3_dot_attribute__context__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/auth/v3/external_auth.proto',
  package='envoy.service.auth.v3',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.service.auth.v3B\021ExternalAuthProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)envoy/service/auth/v3/external_auth.proto\x12\x15\x65nvoy.service.auth.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a-envoy/service/auth/v3/attribute_context.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x17google/rpc/status.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"v\n\x0c\x43heckRequest\x12;\n\nattributes\x18\x01 \x01(\x0b\x32\'.envoy.service.auth.v3.AttributeContext:)\x9a\xc5\x88\x1e$\n\"envoy.service.auth.v2.CheckRequest\"\xc2\x01\n\x12\x44\x65niedHttpResponse\x12\x33\n\x06status\x18\x01 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatusB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x38\n\x07headers\x18\x02 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOption\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t:/\x9a\xc5\x88\x1e*\n(envoy.service.auth.v2.DeniedHttpResponse\"\xc9\x01\n\x0eOkHttpResponse\x12\x38\n\x07headers\x18\x02 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOption\x12\x19\n\x11headers_to_remove\x18\x05 \x03(\t\x12\x35\n\x10\x64ynamic_metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01:+\x9a\xc5\x88\x1e&\n$envoy.service.auth.v2.OkHttpResponse\"\xa7\x02\n\rCheckResponse\x12\"\n\x06status\x18\x01 \x01(\x0b\x32\x12.google.rpc.Status\x12\x44\n\x0f\x64\x65nied_response\x18\x02 \x01(\x0b\x32).envoy.service.auth.v3.DeniedHttpResponseH\x00\x12<\n\x0bok_response\x18\x03 \x01(\x0b\x32%.envoy.service.auth.v3.OkHttpResponseH\x00\x12\x31\n\x10\x64ynamic_metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct:*\x9a\xc5\x88\x1e%\n#envoy.service.auth.v2.CheckResponseB\x0f\n\rhttp_response2e\n\rAuthorization\x12T\n\x05\x43heck\x12#.envoy.service.auth.v3.CheckRequest\x1a$.envoy.service.auth.v3.CheckResponse\"\x00\x42\x45\n#io.envoyproxy.envoy.service.auth.v3B\x11\x45xternalAuthProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_service_dot_auth_dot_v3_dot_attribute__context__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_http__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CHECKREQUEST = _descriptor.Descriptor(
  name='CheckRequest',
  full_name='envoy.service.auth.v3.CheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='envoy.service.auth.v3.CheckRequest.attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.service.auth.v2.CheckRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=445,
)


_DENIEDHTTPRESPONSE = _descriptor.Descriptor(
  name='DeniedHttpResponse',
  full_name='envoy.service.auth.v3.DeniedHttpResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.service.auth.v3.DeniedHttpResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.service.auth.v3.DeniedHttpResponse.headers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.service.auth.v3.DeniedHttpResponse.body', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.service.auth.v2.DeniedHttpResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=642,
)


_OKHTTPRESPONSE = _descriptor.Descriptor(
  name='OkHttpResponse',
  full_name='envoy.service.auth.v3.OkHttpResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.service.auth.v3.OkHttpResponse.headers', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers_to_remove', full_name='envoy.service.auth.v3.OkHttpResponse.headers_to_remove', index=1,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_metadata', full_name='envoy.service.auth.v3.OkHttpResponse.dynamic_metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.service.auth.v2.OkHttpResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=645,
  serialized_end=846,
)


_CHECKRESPONSE = _descriptor.Descriptor(
  name='CheckResponse',
  full_name='envoy.service.auth.v3.CheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.service.auth.v3.CheckResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denied_response', full_name='envoy.service.auth.v3.CheckResponse.denied_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ok_response', full_name='envoy.service.auth.v3.CheckResponse.ok_response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_metadata', full_name='envoy.service.auth.v3.CheckResponse.dynamic_metadata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.service.auth.v2.CheckResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='http_response', full_name='envoy.service.auth.v3.CheckResponse.http_response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=849,
  serialized_end=1144,
)

_CHECKREQUEST.fields_by_name['attributes'].message_type = envoy_dot_service_dot_auth_dot_v3_dot_attribute__context__pb2._ATTRIBUTECONTEXT
_DENIEDHTTPRESPONSE.fields_by_name['status'].message_type = envoy_dot_type_dot_v3_dot_http__status__pb2._HTTPSTATUS
_DENIEDHTTPRESPONSE.fields_by_name['headers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERVALUEOPTION
_OKHTTPRESPONSE.fields_by_name['headers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERVALUEOPTION
_OKHTTPRESPONSE.fields_by_name['dynamic_metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CHECKRESPONSE.fields_by_name['status'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_CHECKRESPONSE.fields_by_name['denied_response'].message_type = _DENIEDHTTPRESPONSE
_CHECKRESPONSE.fields_by_name['ok_response'].message_type = _OKHTTPRESPONSE
_CHECKRESPONSE.fields_by_name['dynamic_metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CHECKRESPONSE.oneofs_by_name['http_response'].fields.append(
  _CHECKRESPONSE.fields_by_name['denied_response'])
_CHECKRESPONSE.fields_by_name['denied_response'].containing_oneof = _CHECKRESPONSE.oneofs_by_name['http_response']
_CHECKRESPONSE.oneofs_by_name['http_response'].fields.append(
  _CHECKRESPONSE.fields_by_name['ok_response'])
_CHECKRESPONSE.fields_by_name['ok_response'].containing_oneof = _CHECKRESPONSE.oneofs_by_name['http_response']
DESCRIPTOR.message_types_by_name['CheckRequest'] = _CHECKREQUEST
DESCRIPTOR.message_types_by_name['DeniedHttpResponse'] = _DENIEDHTTPRESPONSE
DESCRIPTOR.message_types_by_name['OkHttpResponse'] = _OKHTTPRESPONSE
DESCRIPTOR.message_types_by_name['CheckResponse'] = _CHECKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CheckRequest = _reflection.GeneratedProtocolMessageType('CheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKREQUEST,
  '__module__' : 'envoy.service.auth.v3.external_auth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.auth.v3.CheckRequest)
  })
_sym_db.RegisterMessage(CheckRequest)

DeniedHttpResponse = _reflection.GeneratedProtocolMessageType('DeniedHttpResponse', (_message.Message,), {
  'DESCRIPTOR' : _DENIEDHTTPRESPONSE,
  '__module__' : 'envoy.service.auth.v3.external_auth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.auth.v3.DeniedHttpResponse)
  })
_sym_db.RegisterMessage(DeniedHttpResponse)

OkHttpResponse = _reflection.GeneratedProtocolMessageType('OkHttpResponse', (_message.Message,), {
  'DESCRIPTOR' : _OKHTTPRESPONSE,
  '__module__' : 'envoy.service.auth.v3.external_auth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.auth.v3.OkHttpResponse)
  })
_sym_db.RegisterMessage(OkHttpResponse)

CheckResponse = _reflection.GeneratedProtocolMessageType('CheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKRESPONSE,
  '__module__' : 'envoy.service.auth.v3.external_auth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.auth.v3.CheckResponse)
  })
_sym_db.RegisterMessage(CheckResponse)


DESCRIPTOR._options = None
_CHECKREQUEST._options = None
_DENIEDHTTPRESPONSE.fields_by_name['status']._options = None
_DENIEDHTTPRESPONSE._options = None
_OKHTTPRESPONSE.fields_by_name['dynamic_metadata']._options = None
_OKHTTPRESPONSE._options = None
_CHECKRESPONSE._options = None

_AUTHORIZATION = _descriptor.ServiceDescriptor(
  name='Authorization',
  full_name='envoy.service.auth.v3.Authorization',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1146,
  serialized_end=1247,
  methods=[
  _descriptor.MethodDescriptor(
    name='Check',
    full_name='envoy.service.auth.v3.Authorization.Check',
    index=0,
    containing_service=None,
    input_type=_CHECKREQUEST,
    output_type=_CHECKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHORIZATION)

DESCRIPTOR.services_by_name['Authorization'] = _AUTHORIZATION

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/gzip/v4alpha/gzip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.http.compressor.v4alpha import compressor_pb2 as envoy_dot_extensions_dot_filters_dot_http_dot_compressor_dot_v4alpha_dot_compressor__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/gzip/v4alpha/gzip.proto',
  package='envoy.extensions.filters.http.gzip.v4alpha',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.extensions.filters.http.gzip.v4alphaB\tGzipProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5envoy/extensions/filters/http/gzip/v4alpha/gzip.proto\x12*envoy.extensions.filters.http.gzip.v4alpha\x1a\x41\x65nvoy/extensions/filters/http/compressor/v4alpha/compressor.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xdb\x06\n\x04Gzip\x12=\n\x0cmemory_level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\t(\x01\x12k\n\x11\x63ompression_level\x18\x03 \x01(\x0e\x32\x46.envoy.extensions.filters.http.gzip.v4alpha.Gzip.CompressionLevel.EnumB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12l\n\x14\x63ompression_strategy\x18\x04 \x01(\x0e\x32\x44.envoy.extensions.filters.http.gzip.v4alpha.Gzip.CompressionStrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x0bwindow_bits\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x0f(\t\x12P\n\ncompressor\x18\n \x01(\x0b\x32<.envoy.extensions.filters.http.compressor.v4alpha.Compressor\x12>\n\nchunk_size\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 \x1a\x80\x01\n\x10\x43ompressionLevel\"(\n\x04\x45num\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04\x42\x45ST\x10\x01\x12\t\n\x05SPEED\x10\x02:B\x9a\xc5\x88\x1e=\n;envoy.extensions.filters.http.gzip.v3.Gzip.CompressionLevel\"F\n\x13\x43ompressionStrategy\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0c\n\x08\x46ILTERED\x10\x01\x12\x0b\n\x07HUFFMAN\x10\x02\x12\x07\n\x03RLE\x10\x03:1\x9a\xc5\x88\x1e,\n*envoy.extensions.filters.http.gzip.v3.GzipJ\x04\x08\x02\x10\x03J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tR\x0e\x63ontent_lengthR\x0c\x63ontent_typeR\x16\x64isable_on_etag_headerR\x1dremove_accept_encoding_headerBO\n8io.envoyproxy.envoy.extensions.filters.http.gzip.v4alphaB\tGzipProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_filters_dot_http_dot_compressor_dot_v4alpha_dot_compressor__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_GZIP_COMPRESSIONLEVEL_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='envoy.extensions.filters.http.gzip.v4alpha.Gzip.CompressionLevel.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=811,
  serialized_end=851,
)
_sym_db.RegisterEnumDescriptor(_GZIP_COMPRESSIONLEVEL_ENUM)

_GZIP_COMPRESSIONSTRATEGY = _descriptor.EnumDescriptor(
  name='CompressionStrategy',
  full_name='envoy.extensions.filters.http.gzip.v4alpha.Gzip.CompressionStrategy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILTERED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUFFMAN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=921,
  serialized_end=991,
)
_sym_db.RegisterEnumDescriptor(_GZIP_COMPRESSIONSTRATEGY)


_GZIP_COMPRESSIONLEVEL = _descriptor.Descriptor(
  name='CompressionLevel',
  full_name='envoy.extensions.filters.http.gzip.v4alpha.Gzip.CompressionLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GZIP_COMPRESSIONLEVEL_ENUM,
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.extensions.filters.http.gzip.v3.Gzip.CompressionLevel',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=791,
  serialized_end=919,
)

_GZIP = _descriptor.Descriptor(
  name='Gzip',
  full_name='envoy.extensions.filters.http.gzip.v4alpha.Gzip',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory_level', full_name='envoy.extensions.filters.http.gzip.v4alpha.Gzip.memory_level', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\t(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_level', full_name='envoy.extensions.filters.http.gzip.v4alpha.Gzip.compression_level', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_strategy', full_name='envoy.extensions.filters.http.gzip.v4alpha.Gzip.compression_strategy', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window_bits', full_name='envoy.extensions.filters.http.gzip.v4alpha.Gzip.window_bits', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\017(\t', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compressor', full_name='envoy.extensions.filters.http.gzip.v4alpha.Gzip.compressor', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk_size', full_name='envoy.extensions.filters.http.gzip.v4alpha.Gzip.chunk_size', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t*\007\030\200\200\004(\200 ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GZIP_COMPRESSIONLEVEL, ],
  enum_types=[
    _GZIP_COMPRESSIONSTRATEGY,
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.extensions.filters.http.gzip.v3.Gzip',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=1151,
)

_GZIP_COMPRESSIONLEVEL.containing_type = _GZIP
_GZIP_COMPRESSIONLEVEL_ENUM.containing_type = _GZIP_COMPRESSIONLEVEL
_GZIP.fields_by_name['memory_level'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP.fields_by_name['compression_level'].enum_type = _GZIP_COMPRESSIONLEVEL_ENUM
_GZIP.fields_by_name['compression_strategy'].enum_type = _GZIP_COMPRESSIONSTRATEGY
_GZIP.fields_by_name['window_bits'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP.fields_by_name['compressor'].message_type = envoy_dot_extensions_dot_filters_dot_http_dot_compressor_dot_v4alpha_dot_compressor__pb2._COMPRESSOR
_GZIP.fields_by_name['chunk_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP_COMPRESSIONSTRATEGY.containing_type = _GZIP
DESCRIPTOR.message_types_by_name['Gzip'] = _GZIP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Gzip = _reflection.GeneratedProtocolMessageType('Gzip', (_message.Message,), {

  'CompressionLevel' : _reflection.GeneratedProtocolMessageType('CompressionLevel', (_message.Message,), {
    'DESCRIPTOR' : _GZIP_COMPRESSIONLEVEL,
    '__module__' : 'envoy.extensions.filters.http.gzip.v4alpha.gzip_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.gzip.v4alpha.Gzip.CompressionLevel)
    })
  ,
  'DESCRIPTOR' : _GZIP,
  '__module__' : 'envoy.extensions.filters.http.gzip.v4alpha.gzip_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.gzip.v4alpha.Gzip)
  })
_sym_db.RegisterMessage(Gzip)
_sym_db.RegisterMessage(Gzip.CompressionLevel)


DESCRIPTOR._options = None
_GZIP_COMPRESSIONLEVEL._options = None
_GZIP.fields_by_name['memory_level']._options = None
_GZIP.fields_by_name['compression_level']._options = None
_GZIP.fields_by_name['compression_strategy']._options = None
_GZIP.fields_by_name['window_bits']._options = None
_GZIP.fields_by_name['chunk_size']._options = None
_GZIP._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.cluster.v3 import cluster_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto',
  package='envoy.extensions.common.dynamic_forward_proxy.v3',
  syntax='proto3',
  serialized_options=b'\n>io.envoyproxy.envoy.extensions.common.dynamic_forward_proxy.v3B\rDnsCacheProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x12\x30\x65nvoy.extensions.common.dynamic_forward_proxy.v3\x1a%envoy/config/cluster/v3/cluster.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"U\n\x17\x44nsCacheCircuitBreakers\x12:\n\x14max_pending_requests\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"\xda\x04\n\x0e\x44nsCacheConfig\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12U\n\x11\x64ns_lookup_family\x18\x02 \x01(\x0e\x32\x30.envoy.config.cluster.v3.Cluster.DnsLookupFamilyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x41\n\x10\x64ns_refresh_rate\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=\x12\x35\n\x08host_ttl\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x38\n\tmax_hosts\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12N\n\x18\x64ns_failure_refresh_rate\x18\x06 \x01(\x0b\x32,.envoy.config.cluster.v3.Cluster.RefreshRate\x12l\n\x19\x64ns_cache_circuit_breaker\x18\x07 \x01(\x0b\x32I.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheCircuitBreakers\x12\x1f\n\x17use_tcp_for_dns_lookups\x18\x08 \x01(\x08:G\x9a\xc5\x88\x1e\x42\n@envoy.config.common.dynamic_forward_proxy.v2alpha.DnsCacheConfigBY\n>io.envoyproxy.envoy.extensions.common.dynamic_forward_proxy.v3B\rDnsCacheProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_DNSCACHECIRCUITBREAKERS = _descriptor.Descriptor(
  name='DnsCacheCircuitBreakers',
  full_name='envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheCircuitBreakers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_pending_requests', full_name='envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheCircuitBreakers.max_pending_requests', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=397,
)


_DNSCACHECONFIG = _descriptor.Descriptor(
  name='DnsCacheConfig',
  full_name='envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_lookup_family', full_name='envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.dns_lookup_family', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_refresh_rate', full_name='envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.dns_refresh_rate', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t\252\001\0062\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_ttl', full_name='envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.host_ttl', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_hosts', full_name='envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.max_hosts', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_failure_refresh_rate', full_name='envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.dns_failure_refresh_rate', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_cache_circuit_breaker', full_name='envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.dns_cache_circuit_breaker', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_tcp_for_dns_lookups', full_name='envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig.use_tcp_for_dns_lookups', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.config.common.dynamic_forward_proxy.v2alpha.DnsCacheConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=1002,
)

_DNSCACHECIRCUITBREAKERS.fields_by_name['max_pending_requests'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_DNSCACHECONFIG.fields_by_name['dns_lookup_family'].enum_type = envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2._CLUSTER_DNSLOOKUPFAMILY
_DNSCACHECONFIG.fields_by_name['dns_refresh_rate'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DNSCACHECONFIG.fields_by_name['host_ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DNSCACHECONFIG.fields_by_name['max_hosts'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_DNSCACHECONFIG.fields_by_name['dns_failure_refresh_rate'].message_type = envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2._CLUSTER_REFRESHRATE
_DNSCACHECONFIG.fields_by_name['dns_cache_circuit_breaker'].message_type = _DNSCACHECIRCUITBREAKERS
DESCRIPTOR.message_types_by_name['DnsCacheCircuitBreakers'] = _DNSCACHECIRCUITBREAKERS
DESCRIPTOR.message_types_by_name['DnsCacheConfig'] = _DNSCACHECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DnsCacheCircuitBreakers = _reflection.GeneratedProtocolMessageType('DnsCacheCircuitBreakers', (_message.Message,), {
  'DESCRIPTOR' : _DNSCACHECIRCUITBREAKERS,
  '__module__' : 'envoy.extensions.common.dynamic_forward_proxy.v3.dns_cache_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheCircuitBreakers)
  })
_sym_db.RegisterMessage(DnsCacheCircuitBreakers)

DnsCacheConfig = _reflection.GeneratedProtocolMessageType('DnsCacheConfig', (_message.Message,), {
  'DESCRIPTOR' : _DNSCACHECONFIG,
  '__module__' : 'envoy.extensions.common.dynamic_forward_proxy.v3.dns_cache_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfig)
  })
_sym_db.RegisterMessage(DnsCacheConfig)


DESCRIPTOR._options = None
_DNSCACHECONFIG.fields_by_name['name']._options = None
_DNSCACHECONFIG.fields_by_name['dns_lookup_family']._options = None
_DNSCACHECONFIG.fields_by_name['dns_refresh_rate']._options = None
_DNSCACHECONFIG.fields_by_name['host_ttl']._options = None
_DNSCACHECONFIG.fields_by_name['max_hosts']._options = None
_DNSCACHECONFIG._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/auth/cert.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from envoy.api.v2.auth import common_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_common__pb2
from envoy.api.v2.auth import secret_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_secret__pb2
from envoy.api.v2.auth import tls_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_tls__pb2

from envoy.api.v2.auth.common_pb2 import *
from envoy.api.v2.auth.secret_pb2 import *
from envoy.api.v2.auth.tls_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/auth/cert.proto',
  package='envoy.api.v2.auth',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.api.v2.authB\tCertProtoP\001\362\230\376\217\005+\022)envoy.extensions.transport_sockets.tls.v3',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x65nvoy/api/v2/auth/cert.proto\x12\x11\x65nvoy.api.v2.auth\x1a\x1eudpa/annotations/migrate.proto\x1a\x1e\x65nvoy/api/v2/auth/common.proto\x1a\x1e\x65nvoy/api/v2/auth/secret.proto\x1a\x1b\x65nvoy/api/v2/auth/tls.protoB_\n\x1fio.envoyproxy.envoy.api.v2.authB\tCertProtoP\x01\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.transport_sockets.tls.v3P\x01P\x02P\x03\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_auth_dot_common__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_auth_dot_secret__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_auth_dot_tls__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_api_dot_v2_dot_auth_dot_common__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_auth_dot_secret__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_auth_dot_tls__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/ext_authz/v4alpha/ext_authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import config_source_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2
from envoy.config.core.v4alpha import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2
from envoy.type.matcher.v4alpha import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/ext_authz/v4alpha/ext_authz.proto',
  package='envoy.extensions.filters.network.ext_authz.v4alpha',
  syntax='proto3',
  serialized_options=b'\n@io.envoyproxy.envoy.extensions.filters.network.ext_authz.v4alphaB\rExtAuthzProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nBenvoy/extensions/filters/network/ext_authz/v4alpha/ext_authz.proto\x12\x32\x65nvoy.extensions.filters.network.ext_authz.v4alpha\x1a-envoy/config/core/v4alpha/config_source.proto\x1a,envoy/config/core/v4alpha/grpc_service.proto\x1a)envoy/type/matcher/v4alpha/metadata.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x81\x03\n\x08\x45xtAuthz\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12<\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32&.envoy.config.core.v4alpha.GrpcService\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x03 \x01(\x08\x12 \n\x18include_peer_certificate\x18\x04 \x01(\x08\x12N\n\x15transport_api_version\x18\x05 \x01(\x0e\x32%.envoy.config.core.v4alpha.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12L\n\x17\x66ilter_enabled_metadata\x18\x06 \x01(\x0b\x32+.envoy.type.matcher.v4alpha.MetadataMatcher:=\x9a\xc5\x88\x1e\x38\n6envoy.extensions.filters.network.ext_authz.v3.ExtAuthzB[\n@io.envoyproxy.envoy.extensions.filters.network.ext_authz.v4alphaB\rExtAuthzProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_EXTAUTHZ = _descriptor.Descriptor(
  name='ExtAuthz',
  full_name='envoy.extensions.filters.network.ext_authz.v4alpha.ExtAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.ext_authz.v4alpha.ExtAuthz.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.extensions.filters.network.ext_authz.v4alpha.ExtAuthz.grpc_service', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_mode_allow', full_name='envoy.extensions.filters.network.ext_authz.v4alpha.ExtAuthz.failure_mode_allow', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_peer_certificate', full_name='envoy.extensions.filters.network.ext_authz.v4alpha.ExtAuthz.include_peer_certificate', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_api_version', full_name='envoy.extensions.filters.network.ext_authz.v4alpha.ExtAuthz.transport_api_version', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_enabled_metadata', full_name='envoy.extensions.filters.network.ext_authz.v4alpha.ExtAuthz.filter_enabled_metadata', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.extensions.filters.network.ext_authz.v3.ExtAuthz',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=350,
  serialized_end=735,
)

_EXTAUTHZ.fields_by_name['grpc_service'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2._GRPCSERVICE
_EXTAUTHZ.fields_by_name['transport_api_version'].enum_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._APIVERSION
_EXTAUTHZ.fields_by_name['filter_enabled_metadata'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2._METADATAMATCHER
DESCRIPTOR.message_types_by_name['ExtAuthz'] = _EXTAUTHZ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtAuthz = _reflection.GeneratedProtocolMessageType('ExtAuthz', (_message.Message,), {
  'DESCRIPTOR' : _EXTAUTHZ,
  '__module__' : 'envoy.extensions.filters.network.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.ext_authz.v4alpha.ExtAuthz)
  })
_sym_db.RegisterMessage(ExtAuthz)


DESCRIPTOR._options = None
_EXTAUTHZ.fields_by_name['stat_prefix']._options = None
_EXTAUTHZ.fields_by_name['transport_api_version']._options = None
_EXTAUTHZ._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/udp/dns_filter/v3alpha/dns_filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.data.dns.v3 import dns_table_pb2 as envoy_dot_data_dot_dns_dot_v3_dot_dns__table__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/udp/dns_filter/v3alpha/dns_filter.proto',
  package='envoy.extensions.filters.udp.dns_filter.v3alpha',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.filters.udp.dns_filter.v3alphaB\016DnsFilterProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/filters/udp/dns_filter/v3alpha/dns_filter.proto\x12/envoy.extensions.filters.udp.dns_filter.v3alpha\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a!envoy/data/dns/v3/dns_table.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xea\x04\n\x0f\x44nsFilterConfig\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12k\n\rserver_config\x18\x02 \x01(\x0b\x32T.envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig\x12k\n\rclient_config\x18\x03 \x01(\x0b\x32T.envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig\x1a\xa4\x01\n\x13ServerContextConfig\x12\x37\n\x10inline_dns_table\x18\x01 \x01(\x0b\x32\x1b.envoy.data.dns.v3.DnsTableH\x00\x12>\n\x12\x65xternal_dns_table\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceH\x00\x42\x14\n\rconfig_source\x12\x03\xf8\x42\x01\x1a\xb7\x01\n\x13\x43lientContextConfig\x12?\n\x10resolver_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x01\x12\x39\n\x12upstream_resolvers\x18\x02 \x03(\x0b\x32\x1d.envoy.config.core.v3.Address\x12$\n\x13max_pending_lookups\x18\x03 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02(\x01\x42\x61\n=io.envoyproxy.envoy.extensions.filters.udp.dns_filter.v3alphaB\x0e\x44nsFilterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_data_dot_dns_dot_v3_dot_dns__table__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_DNSFILTERCONFIG_SERVERCONTEXTCONFIG = _descriptor.Descriptor(
  name='ServerContextConfig',
  full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inline_dns_table', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig.inline_dns_table', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_dns_table', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig.external_dns_table', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_source', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig.config_source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=578,
  serialized_end=742,
)

_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG = _descriptor.Descriptor(
  name='ClientContextConfig',
  full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resolver_timeout', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig.resolver_timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\0042\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_resolvers', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig.upstream_resolvers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_pending_lookups', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig.max_pending_lookups', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\0042\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=928,
)

_DNSFILTERCONFIG = _descriptor.Descriptor(
  name='DnsFilterConfig',
  full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_config', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.server_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_config', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.client_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DNSFILTERCONFIG_SERVERCONTEXTCONFIG, _DNSFILTERCONFIG_CLIENTCONTEXTCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=928,
)

_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['inline_dns_table'].message_type = envoy_dot_data_dot_dns_dot_v3_dot_dns__table__pb2._DNSTABLE
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['external_dns_table'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.containing_type = _DNSFILTERCONFIG
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.oneofs_by_name['config_source'].fields.append(
  _DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['inline_dns_table'])
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['inline_dns_table'].containing_oneof = _DNSFILTERCONFIG_SERVERCONTEXTCONFIG.oneofs_by_name['config_source']
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.oneofs_by_name['config_source'].fields.append(
  _DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['external_dns_table'])
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['external_dns_table'].containing_oneof = _DNSFILTERCONFIG_SERVERCONTEXTCONFIG.oneofs_by_name['config_source']
_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG.fields_by_name['resolver_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG.fields_by_name['upstream_resolvers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG.containing_type = _DNSFILTERCONFIG
_DNSFILTERCONFIG.fields_by_name['server_config'].message_type = _DNSFILTERCONFIG_SERVERCONTEXTCONFIG
_DNSFILTERCONFIG.fields_by_name['client_config'].message_type = _DNSFILTERCONFIG_CLIENTCONTEXTCONFIG
DESCRIPTOR.message_types_by_name['DnsFilterConfig'] = _DNSFILTERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DnsFilterConfig = _reflection.GeneratedProtocolMessageType('DnsFilterConfig', (_message.Message,), {

  'ServerContextConfig' : _reflection.GeneratedProtocolMessageType('ServerContextConfig', (_message.Message,), {
    'DESCRIPTOR' : _DNSFILTERCONFIG_SERVERCONTEXTCONFIG,
    '__module__' : 'envoy.extensions.filters.udp.dns_filter.v3alpha.dns_filter_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig)
    })
  ,

  'ClientContextConfig' : _reflection.GeneratedProtocolMessageType('ClientContextConfig', (_message.Message,), {
    'DESCRIPTOR' : _DNSFILTERCONFIG_CLIENTCONTEXTCONFIG,
    '__module__' : 'envoy.extensions.filters.udp.dns_filter.v3alpha.dns_filter_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig)
    })
  ,
  'DESCRIPTOR' : _DNSFILTERCONFIG,
  '__module__' : 'envoy.extensions.filters.udp.dns_filter.v3alpha.dns_filter_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig)
  })
_sym_db.RegisterMessage(DnsFilterConfig)
_sym_db.RegisterMessage(DnsFilterConfig.ServerContextConfig)
_sym_db.RegisterMessage(DnsFilterConfig.ClientContextConfig)


DESCRIPTOR._options = None
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.oneofs_by_name['config_source']._options = None
_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG.fields_by_name['resolver_timeout']._options = None
_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG.fields_by_name['max_pending_lookups']._options = None
_DNSFILTERCONFIG.fields_by_name['stat_prefix']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/compressor/v3/compressor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/compressor/v3/compressor.proto',
  package='envoy.extensions.filters.http.compressor.v3',
  syntax='proto3',
  serialized_options=b'\n9io.envoyproxy.envoy.extensions.filters.http.compressor.v3B\017CompressorProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/extensions/filters/http/compressor/v3/compressor.proto\x12+envoy.extensions.filters.http.compressor.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xcc\x08\n\nCompressor\x12\x38\n\x0e\x63ontent_length\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x02\x18\x01\x12\x18\n\x0c\x63ontent_type\x18\x02 \x03(\tB\x02\x18\x01\x12\"\n\x16\x64isable_on_etag_header\x18\x03 \x01(\x08\x42\x02\x18\x01\x12)\n\x1dremove_accept_encoding_header\x18\x04 \x01(\x08\x42\x02\x18\x01\x12\x45\n\x0fruntime_enabled\x18\x05 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlagB\x02\x18\x01\x12\x46\n\x12\x63ompressor_library\x18\x06 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12p\n\x18request_direction_config\x18\x07 \x01(\x0b\x32N.envoy.extensions.filters.http.compressor.v3.Compressor.RequestDirectionConfig\x12r\n\x19response_direction_config\x18\x08 \x01(\x0b\x32O.envoy.extensions.filters.http.compressor.v3.Compressor.ResponseDirectionConfig\x1a\xa2\x01\n\x15\x43ommonDirectionConfig\x12\x39\n\x07\x65nabled\x18\x01 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlag\x12\x38\n\x12min_content_length\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x14\n\x0c\x63ontent_type\x18\x03 \x03(\t\x1a~\n\x16RequestDirectionConfig\x12\x64\n\rcommon_config\x18\x01 \x01(\x0b\x32M.envoy.extensions.filters.http.compressor.v3.Compressor.CommonDirectionConfig\x1a\xc6\x01\n\x17ResponseDirectionConfig\x12\x64\n\rcommon_config\x18\x01 \x01(\x0b\x32M.envoy.extensions.filters.http.compressor.v3.Compressor.CommonDirectionConfig\x12\x1e\n\x16\x64isable_on_etag_header\x18\x02 \x01(\x08\x12%\n\x1dremove_accept_encoding_header\x18\x03 \x01(\x08:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.http.compressor.v2.CompressorBV\n9io.envoyproxy.envoy.extensions.filters.http.compressor.v3B\x0f\x43ompressorProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_extension__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_COMPRESSOR_COMMONDIRECTIONCONFIG = _descriptor.Descriptor(
  name='CommonDirectionConfig',
  full_name='envoy.extensions.filters.http.compressor.v3.Compressor.CommonDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.CommonDirectionConfig.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_content_length', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.CommonDirectionConfig.min_content_length', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.CommonDirectionConfig.content_type', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=992,
)

_COMPRESSOR_REQUESTDIRECTIONCONFIG = _descriptor.Descriptor(
  name='RequestDirectionConfig',
  full_name='envoy.extensions.filters.http.compressor.v3.Compressor.RequestDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.RequestDirectionConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1120,
)

_COMPRESSOR_RESPONSEDIRECTIONCONFIG = _descriptor.Descriptor(
  name='ResponseDirectionConfig',
  full_name='envoy.extensions.filters.http.compressor.v3.Compressor.ResponseDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.ResponseDirectionConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_on_etag_header', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.ResponseDirectionConfig.disable_on_etag_header', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_accept_encoding_header', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.ResponseDirectionConfig.remove_accept_encoding_header', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1321,
)

_COMPRESSOR = _descriptor.Descriptor(
  name='Compressor',
  full_name='envoy.extensions.filters.http.compressor.v3.Compressor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_length', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.content_length', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.content_type', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_on_etag_header', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.disable_on_etag_header', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_accept_encoding_header', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.remove_accept_encoding_header', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_enabled', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.runtime_enabled', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compressor_library', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.compressor_library', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_direction_config', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.request_direction_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_direction_config', full_name='envoy.extensions.filters.http.compressor.v3.Compressor.response_direction_config', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COMPRESSOR_COMMONDIRECTIONCONFIG, _COMPRESSOR_REQUESTDIRECTIONCONFIG, _COMPRESSOR_RESPONSEDIRECTIONCONFIG, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.config.filter.http.compressor.v2.Compressor',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=1379,
)

_COMPRESSOR_COMMONDIRECTIONCONFIG.fields_by_name['enabled'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEFEATUREFLAG
_COMPRESSOR_COMMONDIRECTIONCONFIG.fields_by_name['min_content_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_COMPRESSOR_COMMONDIRECTIONCONFIG.containing_type = _COMPRESSOR
_COMPRESSOR_REQUESTDIRECTIONCONFIG.fields_by_name['common_config'].message_type = _COMPRESSOR_COMMONDIRECTIONCONFIG
_COMPRESSOR_REQUESTDIRECTIONCONFIG.containing_type = _COMPRESSOR
_COMPRESSOR_RESPONSEDIRECTIONCONFIG.fields_by_name['common_config'].message_type = _COMPRESSOR_COMMONDIRECTIONCONFIG
_COMPRESSOR_RESPONSEDIRECTIONCONFIG.containing_type = _COMPRESSOR
_COMPRESSOR.fields_by_name['content_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_COMPRESSOR.fields_by_name['runtime_enabled'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEFEATUREFLAG
_COMPRESSOR.fields_by_name['compressor_library'].message_type = envoy_dot_config_dot_core_dot_v3_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_COMPRESSOR.fields_by_name['request_direction_config'].message_type = _COMPRESSOR_REQUESTDIRECTIONCONFIG
_COMPRESSOR.fields_by_name['response_direction_config'].message_type = _COMPRESSOR_RESPONSEDIRECTIONCONFIG
DESCRIPTOR.message_types_by_name['Compressor'] = _COMPRESSOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Compressor = _reflection.GeneratedProtocolMessageType('Compressor', (_message.Message,), {

  'CommonDirectionConfig' : _reflection.GeneratedProtocolMessageType('CommonDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _COMPRESSOR_COMMONDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.compressor.v3.compressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.compressor.v3.Compressor.CommonDirectionConfig)
    })
  ,

  'RequestDirectionConfig' : _reflection.GeneratedProtocolMessageType('RequestDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _COMPRESSOR_REQUESTDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.compressor.v3.compressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.compressor.v3.Compressor.RequestDirectionConfig)
    })
  ,

  'ResponseDirectionConfig' : _reflection.GeneratedProtocolMessageType('ResponseDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _COMPRESSOR_RESPONSEDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.compressor.v3.compressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.compressor.v3.Compressor.ResponseDirectionConfig)
    })
  ,
  'DESCRIPTOR' : _COMPRESSOR,
  '__module__' : 'envoy.extensions.filters.http.compressor.v3.compressor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.compressor.v3.Compressor)
  })
_sym_db.RegisterMessage(Compressor)
_sym_db.RegisterMessage(Compressor.CommonDirectionConfig)
_sym_db.RegisterMessage(Compressor.RequestDirectionConfig)
_sym_db.RegisterMessage(Compressor.ResponseDirectionConfig)


DESCRIPTOR._options = None
_COMPRESSOR.fields_by_name['content_length']._options = None
_COMPRESSOR.fields_by_name['content_type']._options = None
_COMPRESSOR.fields_by_name['disable_on_etag_header']._options = None
_COMPRESSOR.fields_by_name['remove_accept_encoding_header']._options = None
_COMPRESSOR.fields_by_name['runtime_enabled']._options = None
_COMPRESSOR._options = None
# @@protoc_insertion_point(module_scope)
